@@ -92,13 +92,14 @@ OC.L10N.register(
     "Add mail account" : "Добавяне на профил",
     "Appearance" : "Изглед",
     "List" : "Списък",
+    "Sorting" : "Сортиране",
     "Newest first" : "Първо най-новият",
     "Oldest first" : "Първо най-старият",
-    "Register" : "Регистрация",
     "Shared with me" : "Споделено с мен",
+    "Privacy" : "Поверителност",
     "Security" : "Сигурност",
     "Manage certificates" : "Управление на сертификатите",
-    "Keyboard shortcuts" : "Бързи клавиши",
+    "About" : "Относно",
     "Compose new message" : "Създай ново съобщение",
     "Newer message" : "Следващо съобщение",
     "Older message" : "Предишно съобщение",
@@ -109,7 +110,6 @@ OC.L10N.register(
     "Search" : "Търси",
     "Send" : "Изпрати",
     "Refresh" : "Опресняване",
-    "About" : "Относно",
     "Ok" : "Добре",
     "No certificate" : "Няма сертификат",
     "Certificate updated" : "Актуализиран е сертификат",
@@ -240,7 +240,6 @@ OC.L10N.register(
     "individual" : "Индивидуален",
     "domain" : "домейн",
     "Remove" : "Премахване",
-    "email" : "имейл",
     "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
     "Last hour" : "Последния  час",
@@ -250,6 +249,7 @@ OC.L10N.register(
     "Choose target folder" : "Избор на папка",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
+    "Favorites" : "Любими",
     "Important info" : "Важна информация",
     "Other" : "Друг",
     "Could not send mdn" : "Не можа да се изпрати mdn",
@@ -306,7 +306,6 @@ OC.L10N.register(
     "Delete folder" : "Изтриване на папка",
     "An error occurred, unable to rename the mailbox." : "Възникна грешка, не можа да се преименува пощенската кутия.",
     "Mark all as read" : "Маркирай всички като прочетени",
-    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
     "Add subfolder" : "Добави подпапка",
     "Rename" : "Преименуване",
     "Move folder" : "Преместване на папка",
@@ -314,6 +313,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Изчистете локално кеширани данни, в случай че има проблеми със синхронизирането.",
     "Subscribed" : "Абониран",
     "Sync in background" : "Синхронизиране във фонов режим",
+    "Delete all messages" : "Изтриване на всички съобщения",
     "Outbox" : "Изходящи",
     "New message" : "Ново съобщение",
     "Edit message" : "Редактиране на съобщение",
@@ -363,7 +363,6 @@ OC.L10N.register(
     "Select tags" : "Избор на етикети",
     "Marked as" : "Маркиран/о като",
     "Has attachments" : "Има прикачени файлове",
-    "Last 7 days" : "Последни 7 дни",
     "Sieve Port" : "Порт на Сито",
     "Custom" : "Персонализиран",
     "Sieve User" : "Потребител на Сито",
@@ -412,6 +411,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
     "Train" : "Влак",
     "Stop" : "Спиране /на/",
+    "Deleted" : "Изтрито",
     "Recipient" : "Получател",
     "Help" : "Помощ",
     "contains" : "съдържа",
@@ -529,7 +529,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Моля да се свържете с вашия администратор, за да добавите пощенски профил.",
     "All" : "Всички",
     "Drafts" : "Чернови",
-    "Favorites" : "Любими",
     "Priority inbox" : "Приоритетна папка „Входящи“",
     "All inboxes" : "Всички",
     "Inbox" : "Входящи",
@@ -556,24 +555,7 @@ OC.L10N.register(
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
     "Continue to %s" : "Продължи към %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
-    "Accounts" : "Профили",
-    "Newest" : "Най-новият",
-    "Oldest" : "Най-старият",
-    "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
-    "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
-    "Trusted senders" : "Доверени податели",
-    "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
-    "Contact or email address …" : "Контакт или имейл адрес...",
-    "Subject …" : "Тема...",
-    "Write message …" : "Писане на съобщение ...",
-    "Saving draft …" : "Записване на чернова …",
-    "Loading messages …" : "Зареждане на съобщения ...",
-    "Loading …" : "Зарежда …",
-    "Contact name …" : "Име за контакт …",
-    "Signature …" : "Подпис…",
-    "Saving new tag name …" : "Запазва се името на нов етикет …",
-    "Saving tag …" : "Записване на етикет ..."
+    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
+    "Last 7 days" : "Последни 7 дни"
 },
 "nplurals=2; plural=(n != 1);");
