@@ -90,12 +90,12 @@ OC.L10N.register(
     "General" : "General",
     "Add mail account" : "Agregar cuenta de correo",
     "Appearance" : "Apariencia",
+    "List" : "Lista",
     "Sorting" : "Ordenar",
     "Newest first" : "Más reciente primero",
     "Oldest first" : "Más antiguo primero",
-    "Register" : "Registrar",
     "Security" : "Seguridad",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "About" : "Acerca",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
     "Older message" : "Mensaje más antiguo",
@@ -106,7 +106,6 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
-    "About" : "Acerca",
     "Ok" : "Ok",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
@@ -233,7 +232,6 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "dominio",
     "Remove" : "Eliminar",
-    "email" : "correo electrónico",
     "Itinerary for {type} is not supported yet" : "El itinerario de {type} aún no es compatible",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
     "Last hour" : "Última hora",
@@ -243,6 +241,7 @@ OC.L10N.register(
     "Choose target folder" : "Selecciona la carpeta de destino.",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
+    "Favorites" : "Favoritos",
     "Important info" : "Información importante",
     "Other" : "Otro",
     "Could not send mdn" : "No se pudo enviar la notificación de lectura",
@@ -304,6 +303,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Borrar datos en caché local, en caso de problemas con la sincronización.",
     "Subscribed" : "Suscrito",
     "Sync in background" : "Sincronizar en segundo plano",
+    "Delete all messages" : "Borrar todos los mensajes",
     "Outbox" : "Bandeja de salida",
     "New message" : "Mensaje nuevo",
     "Edit message" : "Editar mensaje",
@@ -422,12 +422,14 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tren desde {depStation} a {arrStation}",
     "Train" : "Tren",
     "Stop" : " detener",
+    "Deleted" : "Eliminado",
     "Recipient" : "Destinatario",
     "Help" : "Ayuda",
     "contains" : "contiene",
     "matches" : "coincide",
     "Actions" : "Acciones",
     "Priority" : "Prioridad",
+    "Tag" : "Etiqueta",
     "delete" : "borrar",
     "Edit" : "Editar",
     "Successfully updated config for \"{domain}\"" : "Configuración actualizada con éxito para \"{domain}\"",
@@ -528,6 +530,7 @@ OC.L10N.register(
     "Private key (optional)" : "Clave privada (opcional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La clave privada solo es necesaria si tienes la intención de enviar correos electrónicos firmados y cifrados usando este certificado.",
     "Submit" : "Enviar",
+    "Guest" : "Invitado",
     "Group" : "Grupo",
     "Shared" : "Compartido",
     "Shares" : "Elementos compartido",
@@ -538,7 +541,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Para agregar una cuenta de correo, contacta a tu administrador.",
     "All" : "Todos",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "Priority inbox" : "Bandeja de entrada prioritaria",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
@@ -569,24 +571,6 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Colocar mi texto en la parte inferior de una respuesta en lugar de en la parte superior.",
-    "Accounts" : "Cuentas",
-    "Newest" : "Más recientes",
-    "Oldest" : "Más antiguos",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
-    "Trusted senders" : "Remitentes de confianza",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
-    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
-    "Subject …" : "Asunto...",
-    "Write message …" : "Escribir mensaje...",
-    "Saving draft …" : "Guardando borrador...",
-    "Loading messages …" : "Cargando mensajes...",
-    "Loading …" : "Loading …",
-    "Contact name …" : "Nombre del contacto ...",
-    "Signature …" : "Firma ...",
-    "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
-    "Saving tag …" : "Guardando etiqueta ..."
+    "Last 7 days" : "Últimos 7 días"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
