@@ -104,10 +104,10 @@ OC.L10N.register(
     "Sorting" : "مرتب سازی",
     "Newest first" : "نخست جدیدترین",
     "Oldest first" : "نخست قدیمی‌ترین",
-    "Register" : "ثبت‌نام",
     "Shared with me" : "Shared with me",
+    "Privacy" : "محرمانگی",
     "Security" : "امنیتی",
-    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
+    "About" : "About",
     "Compose new message" : "نوشتن پیام جدید",
     "Newer message" : "پیام جدیدتر",
     "Older message" : "پیام قدیمی تر",
@@ -118,7 +118,6 @@ OC.L10N.register(
     "Search" : "جستجو",
     "Send" : "ارسال",
     "Refresh" : "تازه‌سازی",
-    "About" : "About",
     "Ok" : "باشه",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
@@ -257,7 +256,6 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "domain",
     "Remove" : "حذف",
-    "email" : "ایمیل",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Last hour" : "Last hour",
@@ -267,6 +265,7 @@ OC.L10N.register(
     "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
+    "Favorites" : "علاقه مندی ها",
     "Important info" : "Important info",
     "Other" : "دیگر",
     "Could not send mdn" : "Could not send mdn",
@@ -320,12 +319,12 @@ OC.L10N.register(
     "Collapse folders" : "پوشه ها را جمع کنید",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
+    "Loading …" : "بارگیری",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "حذف پوشه",
     "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
     "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
-    "Mark all messages of this folder as read" : "تمام پیام های این پوشه را به عنوان خوانده شده علامت گذاری کنید",
     "Add subfolder" : "زیر پوشه را اضافه کنید",
     "Rename" : "تغییرنام",
     "Move folder" : "Move folder",
@@ -333,6 +332,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
     "Subscribed" : "Subscribed",
     "Sync in background" : "Sync in background",
+    "Delete all messages" : "حذف تمام پیام‌ها",
     "Outbox" : "Outbox",
     "New message" : "پیام جدید",
     "Edit message" : "Edit message",
@@ -385,7 +385,6 @@ OC.L10N.register(
     "Select tags" : "برچسب ها را انتخاب کنید",
     "Marked as" : "Marked as",
     "Has attachments" : "Has attachments",
-    "Last 7 days" : "۷ روز گذشته",
     "Sieve Port" : "Sieve Port",
     "Custom" : "Custom",
     "Sieve User" : "Sieve User",
@@ -456,6 +455,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
     "Train" : "رشته",
     "Stop" : "Stop",
+    "Deleted" : "حذف شده",
     "Delete filter" : "Delete filter",
     "Help" : "راهنما",
     "contains" : "contains",
@@ -563,7 +563,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
     "All" : "همه",
     "Drafts" : "پیش نویس",
-    "Favorites" : "علاقه مندی ها",
     "Priority inbox" : "Priority inbox",
     "All inboxes" : "همه صندوق ورودی",
     "Inbox" : "صندوق ورودی",
@@ -594,24 +593,7 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
-    "Accounts" : "حساب‌ها",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
-    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
-    "Trusted senders" : "Trusted senders",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates",
-    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
-    "Subject …" : "موضوع …",
-    "Write message …" : "ارسال پیام ...",
-    "Saving draft …" : "در حال ذخیره پیش نویس ...",
-    "Loading messages …" : "Loading messages …",
-    "Loading …" : "بارگذاری …",
-    "Contact name …" : "Contact name …",
-    "Signature …" : "امضا ...",
-    "Saving new tag name …" : "Saving new tag name …",
-    "Saving tag …" : "Saving tag …"
+    "Mark all messages of this folder as read" : "تمام پیام های این پوشه را به عنوان خوانده شده علامت گذاری کنید",
+    "Last 7 days" : "۷ روز گذشته"
 },
 "nplurals=2; plural=(n > 1);");
