@@ -90,25 +90,22 @@ OC.L10N.register(
     "General" : "Yleiset",
     "Add mail account" : "Lisää sähköpostitili",
     "Appearance" : "Ulkoasu",
+    "Show all messages in thread" : "Näytä kaikki viestit ketjussa",
     "Layout" : "Asettelu",
-    "List" : "Lista",
     "Vertical split" : "Pystysuunnan jako",
     "Horizontal split" : "Vaakasuunnan jako",
+    "List" : "Lista",
     "Sorting" : "Lajittelu",
     "Newest first" : "Uusin ensin",
     "Oldest first" : "Vanhin ensin",
-    "Show all messages in thread" : "Näytä kaikki viestit ketjussa",
-    "Search in body" : "Etsi sisällöstä",
-    "Gravatar settings" : "Gravatar-asetukset",
-    "Register" : "Rekisteröidy",
     "Text blocks" : "Tekstilohkot",
     "New text block" : "Uusi tekstilohko",
     "Shared with me" : "Jaettu kanssasi",
-    "Privacy and security" : "Yksityisyys ja turvallisuus",
+    "Privacy" : "Yksityisyys",
     "Security" : "Tietoturva",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Hallitse varmenteita",
-    "Keyboard shortcuts" : "Pikanäppäimet",
+    "About" : "Tietoja",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
     "Older message" : "Vanhempi viesti",
@@ -119,7 +116,6 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
-    "About" : "Tietoja",
     "Title of the text block" : "Tekstilohkon otsikko",
     "Content of the text block" : "Tekstilohkon sisältö",
     "Ok" : "Ok",
@@ -258,7 +254,6 @@ OC.L10N.register(
     "individual" : "yksittäinen",
     "domain" : "domaini",
     "Remove" : "Poista",
-    "email" : "sähköposti",
     "Add internal address" : "Lisää sisäinen osoite",
     "Last hour" : "Viime tunti",
     "Today" : "Tänään",
@@ -267,6 +262,7 @@ OC.L10N.register(
     "Last month" : "Viime kuukausi",
     "Could not open folder" : "Kansiota ei voitu avata",
     "Choose target folder" : "Valitse kohdekansio",
+    "Favorites" : "Suosikit",
     "Important info" : "Tärkeää tietoa",
     "Other" : "Muu",
     "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
@@ -328,7 +324,6 @@ OC.L10N.register(
     "Delete folder {name}" : "Poista kansio {name}",
     "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
-    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
     "Add subfolder" : "Lisää alikansio",
     "Rename" : "Nimeä uudelleen",
     "Move folder" : "Siirrä kansio",
@@ -336,6 +331,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
     "Subscribed" : "Tilattu",
     "Sync in background" : "Synkronoi taustalla",
+    "Delete all messages" : "Poista kaikki viestit",
     "New message" : "Uusi viesti",
     "Edit message" : "Muokkaa viestiä",
     "Draft" : "Luonnos",
@@ -387,7 +383,6 @@ OC.L10N.register(
     "Tags" : "Tunnisteet",
     "Select tags" : "Valitse tunnisteet",
     "Has attachments" : "On liitteitä",
-    "Last 7 days" : "Edelliset 7 päivää",
     "Sieve Port" : "Sieve-portti",
     "IMAP credentials" : "IMAP-tunnukset",
     "Custom" : "Omavalintainen",
@@ -455,6 +450,7 @@ OC.L10N.register(
     "Train" : "Juna",
     "Stop" : "Pysäytä",
     "Delete action" : "Poista toiminto",
+    "Deleted" : "Poistettu",
     "Sender" : "Lähettäjä",
     "Recipient" : "Vastaanottaja",
     "Create a new mail filter" : "Luo uusi viestisuodatin",
@@ -561,7 +557,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
     "All" : "Kaikki",
     "Drafts" : "Luonnokset",
-    "Favorites" : "Suosikit",
     "Priority inbox" : "Tärkeät saapuneet",
     "All inboxes" : "Kaikki saapuneiden laatikot",
     "Inbox" : "Saapuneet",
@@ -591,28 +586,7 @@ OC.L10N.register(
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
-    "Accounts" : "Tilit",
-    "Newest" : "Uusimmat",
-    "Oldest" : "Vanhimmat",
-    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
-    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
-    "Create a new text block" : "Luo uusi tekstilohko",
-    "Data collection consent" : "Datakeruun suostumus",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
-    "Trusted senders" : "Luotetut lähettäjät",
-    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
-    "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
-    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle",
-    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
-    "Subject …" : "Aihe…",
-    "Write message …" : "Kirjoita viesti…",
-    "Saving draft …" : "Tallennetaan luonnosta…",
-    "Loading messages …" : "Ladataan viestejä …",
-    "Loading …" : "Ladataan…",
-    "Contact name …" : "Yhteystiedon nimi…",
-    "Signature …" : "Allekirjoitus…",
-    "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
-    "Saving tag …" : "Tallennetaan tunnistetta…"
+    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
+    "Last 7 days" : "Edelliset 7 päivää"
 },
 "nplurals=2; plural=(n != 1);");
