@@ -66,11 +66,11 @@ OC.L10N.register(
     "Sorting" : "Razvrstavanje",
     "Newest first" : "Najnoviji prvi",
     "Oldest first" : "Najstariji prvi",
-    "Register" : "Registriraj se",
     "Shared with me" : "Dijeljeno sa mnom",
+    "Privacy" : "Privatnost",
     "Security" : "Sigurnost",
     "Manage certificates" : "Upravljanje vjerodajnicama",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "About" : "Informacije",
     "Compose new message" : "Sastavi novu poruku",
     "Newer message" : "Novija poruka",
     "Older message" : "Starija poruka",
@@ -81,7 +81,6 @@ OC.L10N.register(
     "Search" : "Traži",
     "Send" : "Pošalji",
     "Refresh" : "Osvježi",
-    "About" : "Informacije",
     "Ok" : "U redu",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "From" : "Od",
@@ -151,7 +150,6 @@ OC.L10N.register(
     "individual" : "pojedinac",
     "domain" : "domena",
     "Remove" : "Ukloni",
-    "email" : "e-pošta",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
     "Last hour" : "Posljednji sat",
     "Last week" : "Prošli tjedan",
@@ -159,6 +157,7 @@ OC.L10N.register(
     "Choose target folder" : "Odaberi ciljnu mapu",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
+    "Favorites" : "Favoriti",
     "Important info" : "Važne informacije",
     "Other" : "Ostalo",
     "Could not send mdn" : "Nije moguće poslati mdn",
@@ -211,7 +210,6 @@ OC.L10N.register(
     "Delete folder {name}" : "Izbriši mapu {name}",
     "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
     "Mark all as read" : "Označi sve kao pročitano",
-    "Mark all messages of this folder as read" : "Označi sve poruke u ovoj mapi kao pročitane",
     "Add subfolder" : "Dodaj podmapu",
     "Rename" : "Preimenuj",
     "Move folder" : "Premjesti mapu",
@@ -272,6 +270,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
     "Train" : "Vlak",
+    "Deleted" : "Izbrisano",
     "Recipient" : "Primatelj",
     "Help" : "Pomoć",
     "matches" : "podudara se",
@@ -353,7 +352,6 @@ OC.L10N.register(
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "All" : "Sve",
     "Drafts" : "Skice",
-    "Favorites" : "Favoriti",
     "Priority inbox" : "Prioritetni sandučić",
     "All inboxes" : "Sve dolazne",
     "Inbox" : "Dolazni sandučić",
@@ -377,20 +375,6 @@ OC.L10N.register(
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
     "Continue to %s" : "Idi do %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
-    "Accounts" : "Korisnićki računi",
-    "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
-    "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
-    "Trusted senders" : "Pouzdani pošiljatelji",
-    "Contact or email address …" : "Kontakt ili adresa e-pošte...",
-    "Subject …" : "Naslov...",
-    "Write message …" : "Napiši poruku...",
-    "Saving draft …" : "Spremanje skice...",
-    "Loading …" : "Učitavanje…",
-    "Contact name …" : "Naziv kontakta…",
-    "Signature …" : "Potpis...",
-    "Saving new tag name …" : "Spremanje novog naziva oznake…",
-    "Saving tag …" : "Spremanje oznake..."
+    "Mark all messages of this folder as read" : "Označi sve poruke u ovoj mapi kao pročitane"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
