@@ -31,6 +31,7 @@ OC.L10N.register(
     "Comment" : "Kommentar",
     "Remove" : "Läschen",
     "Today" : "Haut",
+    "Favorites" : "Favoriten",
     "Other" : "Aner",
     "Translate" : "Iwwersetzen",
     "Unnamed" : "ouni Numm",
@@ -45,6 +46,7 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Tags",
     "Custom" : "Individualiséier",
+    "Deleted" : "Geläscht",
     "Help" : "Hëllef",
     "Actions" : "Aktiounen",
     "delete" : "läschen",
@@ -56,8 +58,6 @@ OC.L10N.register(
     "Port" : "Port",
     "Group" : "Grupp",
     "Shared" : "Gedeelt",
-    "All" : "All",
-    "Favorites" : "Favoriten",
-    "Accounts" : "Accounts"
+    "All" : "All"
 },
 "nplurals=2; plural=(n != 1);");
