@@ -97,10 +97,10 @@ OC.L10N.register(
     "List" : "Listă",
     "Newest first" : "Cel mai nou mai întâi",
     "Oldest first" : "Cel mai vechi mai întâi",
-    "Register" : "Înregistrează-te",
     "Shared with me" : "Partajat cu mine",
+    "Privacy" : "Confidențialitate",
     "Security" : "Securitate",
-    "Keyboard shortcuts" : "Scurtături din tastatură",
+    "About" : "Despre",
     "Compose new message" : "Compuneți mesaje noi",
     "Newer message" : "Mesaj mai recent",
     "Older message" : "Mesaj mai vechi",
@@ -111,7 +111,6 @@ OC.L10N.register(
     "Search" : "Caută",
     "Send" : "Trimite",
     "Refresh" : "Reîmprospătează",
-    "About" : "Despre",
     "Ok" : "Ok",
     "No certificate" : "Niciun certificat",
     "Certificate updated" : "Certificatul a fost actualizat",
@@ -248,12 +247,12 @@ OC.L10N.register(
     "More options" : "Mai multe opțiuni",
     "domain" : "domeniu",
     "Remove" : "Elimină",
-    "email" : "email",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nu aveți permisiunea să mutați mesajul în folderul de arhivare și/sau șterge mesajul din folderul curent",
     "Today" : "Azi",
     "Choose target folder" : "Alege directorul destinație",
     "No more submailboxes in here" : "Nu mai sunt subfoldere",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mesajul va fi marcat automat ca important în funcție de mesajele cu care ați interacționat sau pe care le-ați marcat ca importante. La început ar trebui să setați manual importanța pentru antrenarea sistemului, dar aceasta se va îmbunătăți în timp.",
+    "Favorites" : "Favorite",
     "Important info" : "Informații importante",
     "Other" : "Altele",
     "Could not send mdn" : "Eroare la transmiterea mdn",
@@ -371,7 +370,6 @@ OC.L10N.register(
     "Select tags" : "Selectează etichete",
     "Marked as" : "Marcat ca",
     "Has attachments" : "Are atașamente",
-    "Last 7 days" : "Ultimele 7 zile",
     "Enable mail body search" : "Activează căutarea în textul mesajelor",
     "Custom" : "Particularizat",
     "The syntax seems to be incorrect:" : "Sintaxa pare incorectă:",
@@ -421,6 +419,7 @@ OC.L10N.register(
     "Import into {calendar}" : "Importă în {calendar}",
     "Event imported into {calendar}" : "Eveniment importat în {calendar}",
     "Reservation {id}" : "Rezervare {id}",
+    "Deleted" : "Șters",
     "Recipient" : "Destinatar",
     "Help" : "Ajutor",
     "Actions" : "Acțiuni",
@@ -468,7 +467,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Pentru adăugarea unui cont de mail, contactați administratorul.",
     "All" : "Toate ",
     "Drafts" : "Schițe",
-    "Favorites" : "Favorite",
     "All inboxes" : "Toate inbox-urile",
     "Junk" : "Nesolicitate",
     "Sent" : "Trimise",
@@ -496,25 +494,6 @@ OC.L10N.register(
     "The link leads to %s" : "Link-ul duce la %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Dacă nu doriți să vizitați acea pagină, vă puteți întoarce la <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continuă către %s",
-    "Search in the body of messages in priority Inbox" : "Caută în conținutul mesajelor din Inboxul prioritar",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pune textul la sfârșitul răspunsului în loc de deasupra.",
-    "Accounts" : "Conturi",
-    "Newest" : "Cele mai recente",
-    "Oldest" : "Cele mai vechi",
-    "Use Gravatar and favicon avatars" : "Folosiți avataruri Gravatar și favicon",
-    "Register as application for mail links" : "Înregistrează ca aplicație pentru\nlink-urile de mail",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permiteți aplicației să colecteze date despre interacțiunile dumneavoastră. Aplicația se va adapta preferințelor dumneavoastră în funcție de aceste date. Datele sunt stocate doar local.",
-    "Trusted senders" : "Expeditori de încredere",
-    "Manage S/MIME certificates" : "Administrează certificatele  S/MIME",
-    "Contact or email address …" : "Contact sau adresă email ...",
-    "Subject …" : "Subiect ...",
-    "Write message …" : "Scrie mesajul ...",
-    "Saving draft …" : "Se salvează mesajul ...",
-    "Loading messages …" : "Se încarcă mesajele ...",
-    "Loading …" : "Se încarcă…",
-    "Contact name …" : "Nume contact ...",
-    "Signature …" : "Semnătura ...",
-    "Saving new tag name …" : "Se salvează noul nume al etichetei ...",
-    "Saving tag …" : "Se salvează eticheta ..."
+    "Last 7 days" : "Ultimele 7 zile"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
