@@ -73,10 +73,10 @@ OC.L10N.register(
     "Sorting" : "Sortering",
     "Newest first" : "Nyast först",
     "Oldest first" : "Äldst först",
-    "Register" : "Registrera",
+    "Privacy" : "Integritet",
     "Security" : "Säkerhet",
     "Manage certificates" : "Hantera certifikat",
-    "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "About" : "Om",
     "Compose new message" : "Skapa nytt meddelande",
     "Newer message" : "Nyare meddelande",
     "Older message" : "Äldre meddelande",
@@ -87,7 +87,6 @@ OC.L10N.register(
     "Search" : "Sök",
     "Send" : "Skicka",
     "Refresh" : "Uppdatera",
-    "About" : "Om",
     "Ok" : "Ok",
     "Send later" : "Skicka senare",
     "Message {id} could not be found" : "Meddelandet {id} hittades inte",
@@ -180,7 +179,6 @@ OC.L10N.register(
     "individual" : "individ",
     "domain" : "domän",
     "Remove" : "Ta bort",
-    "email" : "e-post",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
     "Last hour" : "Senaste timmen",
     "Today" : "Idag",
@@ -189,6 +187,7 @@ OC.L10N.register(
     "Choose target folder" : "Välj målmapp",
     "No more submailboxes in here" : "Inga fler undermappar här",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
+    "Favorites" : "Favoriter",
     "Important info" : "Viktig info",
     "Other" : "Övrigt",
     "Notify the sender" : "Meddela avsändaren",
@@ -239,7 +238,6 @@ OC.L10N.register(
     "Delete folder {name}" : "Ta bort mapp {name}",
     "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
     "Mark all as read" : "Markera alla som lästa",
-    "Mark all messages of this folder as read" : "Markera alla meddelanden i den här mappen som lästa",
     "Add subfolder" : "Skapa undermapp",
     "Rename" : "Byt namn",
     "Move folder" : "Flytta mapp",
@@ -247,6 +245,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Rensa lokalt cachad data, ifall det finns problem med synkronisering.",
     "Subscribed" : "Prenumeration aktiverad",
     "Sync in background" : "Synkronisera i bakgrunden",
+    "Delete all messages" : "Radera alla meddelanden",
     "Outbox" : "Utkorg",
     "New message" : "Nytt meddelande",
     "Edit message" : "Redigera meddelande",
@@ -275,7 +274,6 @@ OC.L10N.register(
     "Pick an end date" : "Välj ett slutdatum",
     "Tags" : "Taggar",
     "Select tags" : "Välj taggar",
-    "Last 7 days" : "Senaste 7 dagarna",
     "Custom" : "Anpassad",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
@@ -313,6 +311,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
     "Train" : "Tåg",
     "Stop" : "Avsluta",
+    "Deleted" : "Borttagen",
     "Recipient" : "Mottagare",
     "Delete filter" : "Ta bort filter",
     "Help" : "Hjälp",
@@ -353,7 +352,6 @@ OC.L10N.register(
     "Connect your mail account" : "Anslut ditt e-postkonto",
     "All" : "Alla",
     "Drafts" : "Utkast",
-    "Favorites" : "Favoriter",
     "Priority inbox" : "Prioriterad inkorg",
     "All inboxes" : "Alla inkorgar",
     "Inbox" : "Inkorg",
@@ -378,22 +376,7 @@ OC.L10N.register(
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
     "Continue to %s" : "Fortsätt till %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
-    "Accounts" : "Konton",
-    "Newest" : "Nyast",
-    "Oldest" : "Äldst",
-    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
-    "Register as application for mail links" : "Registrera som app för e-postlänkar",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
-    "Trusted senders" : "Betrodda avsändare",
-    "Contact or email address …" : "Kontakt eller e-postadress …",
-    "Subject …" : "Ämne …",
-    "Write message …" : "Skriv meddelande ...",
-    "Saving draft …" : "Sparar utkast ...",
-    "Loading messages …" : "Läser in meddelanden …",
-    "Loading …" : "Läser in ...",
-    "Contact name …" : "Kontaktnamn …",
-    "Signature …" : "Signatur …",
-    "Saving tag …" : "Sparar tagg …"
+    "Mark all messages of this folder as read" : "Markera alla meddelanden i den här mappen som lästa",
+    "Last 7 days" : "Senaste 7 dagarna"
 },
 "nplurals=2; plural=(n != 1);");
