@@ -63,14 +63,12 @@ class FolderMapper {
 			// This is a special folder that must not be shown
 			return !in_array($mailbox['mailbox']->utf8, self::DOVECOT_SIEVE_FOLDERS, true);
 		});
-		return array_map(static function (array $mailbox) use ($account) {
-			return new Folder(
-				$mailbox['mailbox'],
-				$mailbox['attributes'],
-				$mailbox['delimiter'],
-				null,
-			);
-		}, $toPersist);
+		return array_map(static fn (array $mailbox) => new Folder(
+			$mailbox['mailbox'],
+			$mailbox['attributes'],
+			$mailbox['delimiter'],
+			null,
+		), $toPersist);
 	}
 
 	public function createFolder(Horde_Imap_Client_Socket $client,
@@ -129,10 +127,9 @@ class FolderMapper {
 	 */
 	public function getFoldersStatusAsObject(Horde_Imap_Client_Socket $client,
 		array $mailboxes): array {
-		$multiStatus = $client->status($mailboxes);
-
 		$statuses = [];
-		foreach ($multiStatus as $mailbox => $status) {
+		foreach ($mailboxes as $mailbox) {
+			$status = $client->status($mailbox);
 			try {
 				if (!isset($status['messages'], $status['unseen'])) {
 					throw new ServiceException('Could not fetch stats of mailbox: ' . $mailbox);
@@ -145,7 +142,7 @@ class FolderMapper {
 				$this->logger->warning($e->getMessage(), [
 					'exception' => $e,
 					'mailboxes' => $mailboxes,
-					'statuses' => $multiStatus,
+					'status' => $status,
 				]);
 			}
 		}
@@ -205,9 +202,7 @@ class FolderMapper {
 			strtolower(Horde_Imap_Client::SPECIALUSE_TRASH)
 		];
 
-		$attributes = array_map(static function ($n) {
-			return strtolower($n);
-		}, $folder->getAttributes());
+		$attributes = array_map(static fn ($n) => strtolower($n), $folder->getAttributes());
 
 		foreach ($specialUseAttributes as $attr) {
 			if (in_array($attr, $attributes)) {
