@@ -122,9 +122,7 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 
 	private function indexMailboxes(array $mailboxes): array {
 		return array_combine(
-			array_map(static function (Mailbox $mb) : int {
-				return $mb->getId();
-			}, $mailboxes),
+			array_map(static fn (Mailbox $mb): int => $mb->getId(), $mailboxes),
 			$mailboxes
 		);
 	}
