@@ -53,11 +53,10 @@ class Html {
 		$linker = new UrlLinker([
 			'allowFtpAddresses' => true,
 			'allowUpperCaseUrlSchemes' => false,
-			'htmlLinkCreator' => static function ($url) {
+			'htmlLinkCreator' => static fn ($url)
 				// Render full url for the link description. Otherwise, potentially malicious query
 				// params might be hidden.
-				return sprintf('<a href="%1$s">%1$s</a>', htmlspecialchars($url));
-			},
+				=> sprintf('<a href="%1$s">%1$s</a>', htmlspecialchars($url)),
 		]);
 		$data = $linker->linkUrlsAndEscapeHtml($data);
 
